@@ -29,13 +29,13 @@ public:
     /**
      * Destructor
      */
-    virtual ~KHotkeysProxyModel();
+    ~KHotkeysProxyModel() override;
 
     /**
      * Returns true if the item in column @a column should be included in
      * the model.
      */
-    bool filterAcceptsRow(int source_column, const QModelIndex &source_parent) const Q_DECL_OVERRIDE;
+    bool filterAcceptsRow(int source_column, const QModelIndex &source_parent) const override;
 
     /**
      * Get the KHotKeys::ActionDataBase behind the index.
