@@ -24,14 +24,14 @@ public:
                         Condition_list *conditions_P = nullptr,
                         ActionList *actions_P = nullptr);
 
-    ~Generic_action_data();
+    ~Generic_action_data() override;
 
     /**
      * Visitor pattern
      * @reimp
      */
-    void accept(ActionDataVisitor *visitor) Q_DECL_OVERRIDE;
-    void accept(ActionDataConstVisitor *visitor) const Q_DECL_OVERRIDE;
+    void accept(ActionDataVisitor *visitor) override;
+    void accept(ActionDataConstVisitor *visitor) const override;
 
     // CHECKME: Why this?
     using ActionData::add_action; // make public
